bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 24. Aventiure
___________________________________________________ #### Aventivre wie die boten ze rine qvamen #### vnd wie si danne schieden
###### 1422 | ### Do ecel zv dem rine | sine boten sande ### do flvgen disiv maere | von lande ze lande ### mit boten harte snellen | er bat vnd ovch gebot ### zv siner hohgecite | des holte maniger da den tot
###### 1423 | ### di boten dannen fvren | vzer hivnen lant ### zv den bvrgonden | dar waren si gesant ### nach drin edeln kvenegen | vnd ovch nach ir man ### si solden chomen ecele | des man do gahen began
###### 1424 | ### hin ze bechelaren | chomen si geritten ### da diente man in gerne | daz en wart da niht vermiten ### rvedeger sinen dienest | enbot vnd gotelint ### bi in hin ze rine | vnd ovch ir beider liebez chint
###### 1425 | ### si ne liezens ane gabe | von in niht scheiden dan ### daz deste baz gefveren | di ecelen man ### vten vnd ir chinden | enbot do rvedeger ### si ne heten in so waege | deheinen margraven mer
###### 1426 | ### sin enbvten ovch prvnhilte | dienest vnd gvt ### staetechliche triwe | vnd willigen mvet ### do si di rede vernamen | di boten wolden varn ### si bat div margravinne | got von himele bewarn
###### 1427 | ### e daz di boten chomen | wol dvrch peyrlant ### waerbel der vil snelle | den gvten bisschoff vant ### waz der do sinen frivnden | hin ce rine enbot ### daz ist mir niht gewizen | niwan sin golt also rot
###### 1428 | ### gap er den boten ze minne | riten er si lie ### do sprach der bissof bilgrim | vnde sold ich si sehen hie ### mir waere wol ce mvte | di swestersvene min ### wand ich mach vil selten | zv zin chomen an den rin
###### 1429 | ### welhe waege si fveren | ce rine dvrch div lant ### des chan ich niht bescheiden | ir silber vnt gewant ### daz nam in niemen | man vorht ir herren zorn ### ia was gewaltech | der edele chvnech wol geborn
###### 1430 | ### inner tagen zwelfen | chomens an den rin ### ze wormez zv dem lande | waerbel vnd swemmelin ### do sagt man div maere | den chvenegen vnd ir man ### do chomen boten vremde | gventher do vragen began
###### 1431 | ### do sprach der vogt von rine | wer tvt vns daz bechant ### von wannen dise vremden | riten in daz lant ### daz en wesse niemen | vnze daz si sach ### hagen von tronege | do ce gventhern sprach
###### 1432 | ### vns choment niwiv maere | des wil ich iv veriehen ### di eceln videlaere | di han ich hie gesehen ### si hat iwer swester | gesendet an den rin ### si sveln vns dvrch ir herren | groze willechomen sin
###### 1433 | ### si ritten al bereite | fver den palas dan ### ez gefvren nie herlicher | fversten spileman ### des chveneges ingesinde | enpfiengen sa cehant ### man gap in schoen herberge | vnt hiez behalten ir gewant
###### 1434 | ### ir reisechleider waren | rich vnd so wolgetan ### ia mohten si mit eren | fver den kvenich gan ### der en wolden si niht mere | da ce hove tragen ### ob ir iemen rvchte | di boten hiezen iz da sagen
###### 1435 | ### in der selben maze | man ovch livte vant ### di ez vil gerne namen | den wart ez gesant ### do leiten an di geste | verre bezer wat ### als ez boten chvenege | ce tragen herliche stat
###### 1436 | ### do gie mit vrlovbe | da der kvenech saz ### daz eceln gesinde | gerne sach man daz ### hagen zvetechliche | gegen den boten spranch ### vnt enpfie si minnechliche | des sageten im di knappen danch
###### 1437 | ### dvrch div chvnden maere | vragen er began ### wi sich ecel gehabte | vnd sine man ### do sprach der videlaere | daz lant gestvnt ni baz ### noch so vro di livte | nv wizzet endechliche daz
###### 1438 | ### si giengen zv dem wirte | der palas der was vol ### do enpfie man di geste | so man von rehte sol ### so gvetlichez grvezen | in ander chvenige lant ### waerbel vil der recken | da bi gvnthern vant
###### 1439 | ### der chvenech gezogenliche | grvzen si began ### sit willechomen ir beide | ir hivnen spilman ### vnd iwer hergesellen | hat ivch her gesant ### ecel der vil riche | zv der bvrgonden lant
###### 1440 | ### si nigen dem chvnige | do sprach waerbelin ### dir enbivtet holden dienest | der liebe herre min ### vnd criemhilt din swester | her in dize lant ### si habent vns iv recken | vf gvte triwe gesant
###### 1441 | ### do sprach der kvenech riche | der maere bin ich vro ### wi gehabt sich ecel | so vragt der degen do ### vnd criemhilt min swester | vzzer hivnen lant ### do sprach der videlaere | div maere tvn ich iv bechant
###### 1442 | ### daz sich noch nie gehabten | deheine livte baz ### danne si sich gehabent beide | wizzet daz ### vnd allez ir gedigene | di mage vnd ovch ir man ### si vrevten sich der verte | do wir schieden von dan
###### 1443 | ### genade siner dieneste | di er mir enboten hat ### vnd miner swester | sit ez also stat ### daz si lebent mit frevden | der kvenech vnd sine man ### wand ich doh der maere | gefragt sorgende han
###### 1444 | ### di zwene ivnge chvenege | di waren ovch nv chomen ### si heten disiv maere | alrerst do vernomen ### dvrch siner swester liebe | di boten gerne sach ### giselher der ivnge | zv zin minnechlichen sprach
###### 1445 | ### ir boten soldet vnz groze | willechome sin ### ob ir dicher woldet | her riten an den rin ### ir fvendet hie di frivnde | di ir gerne moehtet sehen ### iv solde hie ce lande | vil wenich leides geschehen
###### 1446 | ### wir triwen iv aller eren | sprach do swemmelin ### ine chonde iv niht bedivten | mit den sinnen min ### wi rehte minnechlichen | iv ecel enboten hat ### vnt iwer edel swester | der dinch in hohen eren stat
###### 1447 | ### genade vnde triwe | mant ivh des kveneges wip ### vnt daz ir ie was waege | iwer herce vnt iwer lip ### vnt ce vorderste dem chvenege | sin wir her gesant ### daz ir gervchet riten | in daz eceln lant
###### 1448 | ### daz wir ivch des baeten | vil vast vns daz gebot ### ecel der riche | iv allen daz enbot ### ob ir ivch iwer swester | niht sehen woldet lan ### so wold er doch gerne wizzen | waz er iv hete getan
###### 1449 | ### daz ir in also vremdet | vnt ovch siniv lant ### ob iv div chveneginne | waere ni bechant ### so moeht er doch verdienen | daz ir in rvchet sehen ### swenne daz ergienge | so waer im liebe geschehen
###### 1450 | ### do sprach der chvenech gvnther | veber dise siben naht ### so chvend ich div maere | wes ich mich han bedaht ### mit den minen frivnden | di wile svlt ir gan ### in iwer herberge | vnd svelt vil gvote ruwe han
###### 1451 | ### do sprach aber waerbelin | vnt moeht daz geschehen ### daz wir mine vrowen | chonden e gesaehen ### vten di vil richen | e wir schveffen vns gemach ### giselher der edele | do vil zvehtechlichen sprach
###### 1452 | ### daz sol iv niemen wenden | welt ir fver si gan ### ir habt miner mvter | willen gar getan ### want sie sihet ivch gerne | dvrch di swester min ### vrovn criemhilden | ir svlt ir willechomen sin
###### 1453 | ### giselher si brahte | da er di vrowen vant ### di boten sach si gerne | von der hivnen lant ### si grvztes minnechliche | dvrh ir tvgende mvt ### do sagten ir div maere | di boten hoffsh vnde gvt
###### 1454 | ### ia enbivtet iv min vrowe | so sprach swemmelin ### dienest vnde triwe | mohte daz gesin ### daz si ivch diche saehe | ir svlt gelovben daz ### so waer ir in der werlde | mit deheinen vrevden baz
###### 1455 | ### do sprach div chveneginne | des en mach niht gesin ### swie gerne ich dicke saehe | di lieben tohter min ### so ist mir leider ce verre | des edeln chveneges wip ### nv si immer saelich | ir vnd eceln lip
###### 1456 | ### ir svlt mich lazen wizen | e irz gervmet hie ### wenne ir wider wellet | ine gesach so gerne nie ### boten in langen ziten | denne ich ivch han gesaehen ### di chnappen ir do lobten | daz si daz liezen geschehen
###### 1457 | ### zen herbergen fvren | di von hivnen lant ### do het der kvenech riche | nach frivnden sin gesant ### gventher der edele | vragte sine man ### wi in div rede geviele | vil maniger do sprechen began
###### 1458 | ### daz er wol moehte riten | in eceln lant ### daz rieten im di besten | di er da vnder vant ### ane hagen eine | dem was ez grimme leit ### er sprach zem kvenige tovgen | ir habt iv selben widerseit
###### 1459 | ### nv ist iv doch gewizen | waz wir haben getan ### wir mvegen immer sorge | zv criemhilde han ### wand ich slvch ze tode | ir man mit miner hant ### wie getorste wir riten | in daz eceln lant
###### 1460 | ### do sprach der kvnech riche | min swester lie den zorn ### mit chvsse minnecliche | si hat vf vns verchorn ### daz wir ir ie getaten | e si von hinnen reit ### ez en si et hagen | danne iv einem widerseit
###### 1461 | ### nv lat ivch niht betragen | sprach hagene swes si iehen ### di boten von den hivnen | welt ir criemhilde sehen ### ir mvegt da verliesen | di ere vnd ovch den lip ### ia ist vil lanchraeche | des kvenech eceln wip
###### 1462 | ### do sprach zv dem rate | der fverste gernot ### sit ir von schvlden | fverhtet da den tot ### in hivnisschen richen | solde wirz darvmbe lan ### wir en saehen vnser swester | daz waere vil vbele getan
###### 1463 | ### do sprach der fverste giselher | zv dem degene ### sit ir ivch schvldech wizet | frivnt hagene ### so svlt ir hi beliben | vnt ivch wol bewarn ### vnd lazet di getverren | zv miner swester mit vns varn
###### 1464 | ### do begonde zvernen | von tronege der degen ### ine wil daz ir iemen | fverhtet vf den wegen ### der getverre riten | mit iv ce hove baz ### sit ir niht welt erwinden | ich sol iv wol erzeigen daz
###### 1465 | ### do sprach der cvchenmeister | rvmolt der degen ### der vremden vnt der chvnden | mohtet ir wol heizen pflegen ### nach iwer selbes willen | wand ir habet vollen rat ### ich waene niht daz hagene | ivch noch vergiselt hat
###### 1466 | ### welt ir niht volgen hagene | iv raetet rvmolt ### wand ich iv bin mit triwen | vil dienestlichen holt ### daz ir svlt hi beliben | dvrch den willen min ### vnde lat den kvenech ecel | dort bi criemhilde sin
###### 1467 | ### wi chvnde iv in der werlde | immer sanfter wesen ### ir mvegt vor iwern finden | harte wol genesen ### ir svlt mit gvten chleidern | zieren wol den lip ### trinchet win den besten | vnt minnet waerltlichiv wip
###### 1468 | ### darzv git man iv spise | di besten di e gewan ### in der werlt kvenech deheiner | ob des niht moeht ergan ### ir soldet noh beliben | dvrch iwer schoene wip ### e ir so chintliche | soldet wagen den lip
###### 1469 | ### des rat ich beliben | rich sint iwer lant ### man mach iv baz erloesen | hie heime div pfant ### danne da cen hivnen | wer weiz wie iz da gestat ### ir svlt beliben herren | daz ist der rvmoldes rat
###### 1470 | ### wir wellen niht beliben | sprach do gernot ### sit daz vns min swester | so minnechlich enbot ### vnt ecel der riche | zwiv solde wir daz lan ### der dar niht gerne welle | der mach hi heime bestan
###### 1471 | ### des antwurte hagene | lat ivh vnblinden niht ### mine rede darvmbe | swi halt iv geschit ### ich rat iv an den triwen | welt ir ivch bewarn ### so svlt ir zv den hivnen | vil gewaerliche varn
###### 1472 | ### sit ir niht welt erwinden | so besendet iwer man ### di besten di ir vindet | oder inder mveget han ### so wel ich vz in allen | tvsent ritter gvt ### so ne mag iv niht gewerren | der argen criemhilde mvt
###### 1473 | ### des wil ich gerne volgen | sprach der kvenech zehant ### do hiez er boten riten | witen in siniv lant ### do brahte man der helde | driv tvsent oder mer ### si ne wanden niht ce rwerben | also grozlichiv ser
###### 1474 | ### si ritten vroeliche | in gventheres lant ### man hiez in allen geben | ross vnt ovh gewant ### di da varen solden | von bvergonden dan ### der kvenech mit gvtem willen | der vil manegen gewan
###### 1475 | ### do hiez von tronege hagene | danchwart der brvder sin ### ir beider rechen ahzech | fveren an den rin ### di chomen ritterliche | harnassh vnt gewant ### fvrten di vil snellen | in daz gvntheres lant
###### 1476 | ### do chom der chvene volker | ein edel spilman ### zv der hovereise | mit drizech siner man ### di heten soelech gewaete | ez moeht ein chvenech tragen ### daz er zen hivnen wolde | daz hiez er gventhere sagen
###### 1477 | ### wer der volker waere | daz wil ich ivch wizen lan ### er was ein edel herre | im was ovch vndertan ### vil der gvten rechen | in bvrgonden lant ### dvrch daz er videln chonde | do was er der spilman genant
###### 1478 | ### hagen welte tvsent | di het er wol bechant ### vnt swaz in starchn striten | gefrvemt het ir hant ### oder swaz si ie begiengen | des het er vil gesehen ### den chonde anders niemen | niwan frvemcheite iehen
###### 1479 | ### di boten criemhilde | vil sere da verdroz ### wande ir vorhte cir herren | div was harte groz ### si gerten taegeliche | vrlovbes von dan ### des en gonde in niht hagene | daz was dvrch liste getan
###### 1480 | ### er sprach zv sinem herren | wir sveln daz bewarn ### daz wir si lazen riten | e daz wir selbe varn ### darnach in siben tagen | in eceln lant ### treit vns iemen argen villen | deist vns deste baz bechant
###### 1481 | ### so ne mach ovch sich vrov criemhilt | bereiten niht darzv ### daz vns dvrh ir rate | iemen schaden tv ### hat aber si den willen | ez mach ir leide ergan ### wir fveren mit vns hinnen | so manigen vzerwelten man
###### 1482 | ### schilde vnd saetele | vnt allez ir gewant ### daz si fveren wolden | in eceln lant ### daz was bereitet nv gar | vil manigem chvenem man ### di boten criemhilde | hiez man fver gvntheren gan
###### 1483 | ### do di boten chomen | do sprach gernot ### der kvenech wil gevolgen | des vns ecel her enbot ### wir wellen chomen gerne | ce siner hohgecit ### vnd sehen vnser swester | daz ir des ane zwifel sit
###### 1484 | ### do sprach der kvenech gventher | chvennet ir vns gesagen ### wenne si div hohzit | oder in welhen tagen ### wir dar chomen solden | do sprach swemmelin ### cen naehesten svenewenden | sol si waerliche sin
###### 1485 | ### der kvenich in erlovbte | des was noh niht geschehen ### ob si wolden gerne | frovn prvennhilde sehen ### daz si fver si solden | mit sinem willen gan ### daz vnderstvnt do volker | daz was ir liebe getan
###### 1486 | ### ia ne ist min vrowe prvennhilt | nv niht so wol gemvt ### daz ir si mveget schowen | sprach der ritter gvt ### bitet vnz morgn | so lat mans ivch sehen ### do si sie wanden schowen | do ne chvndes niht geschehen
###### 1487 | ### do hiez der fverste riche | er was den boten holt ### dvrch sine selbes tvgende | tragen dar sin golt ### vffe den breiten schilden | der moht er vile han ### ovch wart in richiv gabe | von sinen vrivnden getan
###### 1488 | ### giselher vnd gernot | gere vnd oertwin ### daz si ovch milte waren | daz taten si wol shin ### also riche gabe | bvten si di boten an ### daz si se vor ir herren | niht getorsten enpfan
###### 1489 | ### do sprach zv dem kvenige | der bote waerbelin ### her kvenich lat iwer gabe | hi ze lande sin ### wir mvegen ir doch niht fveren | mine herre iz vns verbot ### daz wir iht gabe naemen | ovch ist es harte lvecel not
###### 1490 | ### do wart der vogt von rine | davon vil vngemvt ### daz si versprechen wolden | so riches kveneges gvt ### doch mvosen si enpfahen | sin golt vnd sin gewant ### daz si mit in fvorten | sit in ecelen lant
###### 1491 | ### si wolden sehen vten | e si schieden dan ### giselher der snelle | der braht di spileman ### fver sine mvoter vten | div vrowe enbot von dan ### swaz si ern hete | daz waer ir liebe getan
###### 1492 | ### do hiez div chveneginne | ir porten vnd ir golt ### geben dvrch criemhilde | want der was si holt ### vnt dvrch den kvenech ecel | den selben spileman ### si mohtenz gern enpfahen | ez was mit triwen getan
###### 1493 | ### vrlovp genomen heten | di boten nv von dan ### von wiben vnd von mannen | vroelich si do dan ### fvoren in ce swaben | dar hiez si gernot ### sine helde leiten | daz ez in niemen missebot
###### 1494 | ### do sich di von in schieden | di ir solden pflegen ### herschaft div eceln | vridet vf allen wegen ### des en nam in niemen | ross noch ir gewant ### si ilten harte balde | in daz ecelen lant
###### 1495 | ### swa si der vrivnt iht wessen | daz taten si den chvnt ### daz di bvrgonden | in vil chvrzer stvnt ### choemen her von rine | in der hivnen lant ### dem bissoffe pilgerime | wart ovch daz maere bechant
###### 1496 | ### da si fver bechelaren | di straze nider ritten ### man saget ez rvedger | daz en wart niht vermitten ### vnde gotelinde | des margraven wip ### daz si si sehen solde | des wart vil vroelich ir lip
###### 1497 | ### gahen mit den maeren | sah man di spilman ### eceln si fvnden | in der stat ze gran ### dienest veber dienest | der man im vil enbot ### sageten si dem kvenige | vor liebe wart er frevden rot
###### 1498 | ### do div chveneginne | div maere reht ervant ### daz ir brvder solden | chomen in daz lant ### do was ir wol ce mvte | si lonte den spileman ### mit vil grozer gabe | daz was ir ere getan
###### 1499 | ### si sprach nv sagt beide | waerbel vnd swemmelin ### welhe mine mage | cer hohzit wellen sin ### der besten di wir ladeten | her in dize lant ### nv sagt waz redete hagene | do er div maere bevant
###### 1500 | ### er sprach der chom cer sprache | an einem morgen frv ### lvecel gvter sprveche | redet er derzv ### do si di reise lobten | her in hivnen lant ### daz was dem grimmem hagene | gar cem tode genant
###### 1501 | ### ez chvment iwer brvder | di chvenige alle dri ### in herlichem mvote | swer mer damite si ### der maere ich enedechlichen | wizzen nine chan ### ez lobt mit in riten | volker der chvene spileman
###### 1502 | ### des enbaer ich harte lihte | sprach des kveneges wip ### deich immer saehe | den volkeres lip ### hagenen bin ich waege | der ist ein helt vil gvt ### daz wir in saehen mvezen | des stat mir hohe der mvt
###### 1503 | ### do gie div chveneginne | da si den kvenech sach ### wi rehte minnechliche | criemhilt do sprach ### wi gevallent iv div maere | lieber herre min ### des ie min wille gerte | daz sol nv verendet sin
###### 1504 | ### din wille deist min vrevde | sprach der kvenich do ### ine wart min selbes mage | ni so rehte vro ### ob si iemer chomen solden | her in miniv lant ### dvrh liebe diner frivnde | so ist min sorge verswant
###### 1505 | ### des chveneges ammetlivte | di hiezen veber al ### mit gesidele rihten | palas vnd sal ### gegen den lieben gesten | di in da solden chomen ### sit wart von in dem chvenege | vil michel weinen benomen

<<< Übersicht <<< vorige Seite nächste Seite >>>